"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMediaBuffering = void 0;
const react_1 = require("react");
const use_buffer_state_1 = require("./use-buffer-state");
const useMediaBuffering = ({ element, shouldBuffer, isPremounting, }) => {
    const buffer = (0, use_buffer_state_1.useBufferState)();
    (0, react_1.useEffect)(() => {
        let cleanup = () => undefined;
        const { current } = element;
        if (!current) {
            return;
        }
        if (!shouldBuffer) {
            return;
        }
        if (isPremounting) {
            return;
        }
        const onWaiting = () => {
            const { unblock } = buffer.delayPlayback();
            const onCanPlay = () => {
                unblock();
            };
            const onError = () => {
                unblock();
            };
            current.addEventListener('canplay', onCanPlay, {
                once: true,
            });
            current.addEventListener('error', onError, {
                once: true,
            });
            cleanup = () => {
                current.removeEventListener('canplay', onCanPlay);
                current.removeEventListener('error', onError);
                unblock();
                return undefined;
            };
        };
        if (current.readyState < current.HAVE_FUTURE_DATA) {
            onWaiting();
        }
        else {
            current.addEventListener('waiting', onWaiting);
        }
        return () => {
            cleanup();
        };
    }, [buffer, element, isPremounting, shouldBuffer]);
};
exports.useMediaBuffering = useMediaBuffering;
